==> biomaj-watcher_1.0.orig.tar.gz: biomaj-watcher_1.0/external_deps/smartgwt/main/src/com/smartgwt/client/docs/TreeIcons.java <==

package com.smartgwt.client.docs;

/**
 * @see com.smartgwt.client.widgets.tree.TreeGrid#setNodeIcon
 * @see com.smartgwt.client.widgets.tree.TreeNode#getIcon
 * @see com.smartgwt.client.widgets.tree.TreeNode#getShowOpenIcon
 * @see com.smartgwt.client.widgets.tree.TreeNode#getShowDropIcon
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getIconSize
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getOpenerIconSize
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getFolderIcon
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getDropIconSuffix
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getOpenIconSuffix
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getClosedIconSuffix
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getNodeIcon
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getShowOpenIcons
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getShowDropIcons
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getCustomIconProperty
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getCustomIconOpenProperty
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getCustomIconDropProperty
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getShowCustomIconOpen
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getShowCustomIconDrop
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getShowConnectors
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getShowFullConnectors
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getOpenerImage
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getConnectorImage
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getFolderIcon
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getCustomIconProperty
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getNodeIcon
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getOpenIconSuffix
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getClosedIconSuffix
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getShowOpenIcons
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getShowCustomIconOpen
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getCustomIconOpenProperty
 */
public interface TreeIcons {
}

==> biomaj-watcher_1.2.1.orig.tar.gz: biomaj-watcher_1.2.1/external_deps/smartgwt/main/src/com/smartgwt/client/docs/TreeIcons.java <==

package com.smartgwt.client.docs;

/**
 * The following APIs are all related to TreeIcons.
 * @see com.smartgwt.client.widgets.tree.TreeGrid#setNodeIcon
 * @see com.smartgwt.client.widgets.tree.TreeNode#getIcon
 * @see com.smartgwt.client.widgets.tree.TreeNode#getShowOpenIcon
 * @see com.smartgwt.client.widgets.tree.TreeNode#getShowDropIcon
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getIconSize
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getOpenerIconSize
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getFolderIcon
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getDropIconSuffix
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getOpenIconSuffix
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getClosedIconSuffix
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getNodeIcon
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getShowOpenIcons
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getShowDropIcons
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getCustomIconProperty
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getCustomIconOpenProperty
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getCustomIconDropProperty
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getShowCustomIconOpen
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getShowCustomIconDrop
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getShowConnectors
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getShowFullConnectors
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getOpenerImage
 * @see com.smartgwt.client.widgets.tree.TreeGrid#getConnectorImage
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getFolderIcon
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getCustomIconProperty
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getNodeIcon
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getOpenIconSuffix
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getClosedIconSuffix
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getShowOpenIcons
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getShowCustomIconOpen
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getCustomIconOpenProperty
 * @see com.smartgwt.client.widgets.grid.ColumnTree#getShowMultipleColumns
 */
public interface TreeIcons {
}
